# Edit Site

Namespace: `core/edit-site`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/edit-site/src/store/selectors.js) -->

### getCanUserCreateMedia

Returns whether the current user can create media or not.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Whether the current user can create media or not.

### getCurrentTemplateNavigationPanelSubMenu

Returns the current template or template part's corresponding
navigation panel's sub menu, to be used with `openNavigationPanelToMenu`.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: The current template or template part's sub menu.

### getCurrentTemplateTemplateParts

Returns the template parts and their blocks for the current edited template.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Array`: Template parts and their blocks in an array.

### getEditedPostId

Returns the ID of the currently edited template or template part.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string?`: Post ID.

### getEditedPostType

Returns the current edited post type (wp_template or wp_template_part).

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `TemplateType?`: Template type.

### getEditorMode

Returns the current editing mode.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: Editing mode.

### getHomeTemplateId

Returns the current home template ID.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `number?`: Home template ID.

### getNavigationPanelActiveMenu

Returns the active menu in the navigation panel.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: Active menu.

### getPage

Returns the current page object.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Page.

### getReusableBlocks

Returns any available Reusable blocks.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Array`: The available reusable blocks.

### getSettings

Returns the settings, taking into account active features and permissions.

_Parameters_

-   _state_ `Object`: Global application state.
-   _setIsInserterOpen_ `Function`: Setter for the open state of the global inserter.

_Returns_

-   `Object`: Settings.

### isFeatureActive

Returns whether the given feature is enabled or not.

_Parameters_

-   _state_ `Object`: Global application state.
-   _featureName_ `string`: Feature slug.

_Returns_

-   `boolean`: Is active.

### isInserterOpened

Returns the current opened/closed state of the inserter panel.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: True if the inserter panel should be open; false if closed.

### isListViewOpened

Returns the current opened/closed state of the list view panel.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: True if the list view panel should be open; false if closed.

### isNavigationOpened

Returns the current opened/closed state of the navigation panel.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: True if the navigation panel should be open; false if closed.

<!-- END TOKEN(Autogenerated selectors|../../../packages/edit-site/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/edit-site/src/store/actions.js) -->

### addTemplate

Action that adds a new template and sets it as the current template.

_Parameters_

-   _template_ `Object`: The template.

_Returns_

-   `Object`: Action object used to set the current template.

### closeGeneralSidebar

Action that closes the sidebar.

### openGeneralSidebar

Action that opens an editor sidebar.

_Parameters_

-   _name_ `?string`: Sidebar name to be opened.

### openNavigationPanelToMenu

Opens the navigation panel and sets its active menu at the same time.

_Parameters_

-   _menu_ `string`: Identifies the menu to open.

### removeTemplate

Action that removes a template.

_Parameters_

-   _template_ `Object`: The template object.

### revertTemplate

Reverts a template to its original theme-provided file.

_Parameters_

-   _template_ `Object`: The template to revert.
-   _options_ `[Object]`:
-   _options.allowUndo_ `[boolean]`: Whether to allow the user to undo reverting the template. Default true.

### setHomeTemplateId

Action that sets the home template ID to the template ID of the page resolved
from a given path.

_Parameters_

-   _homeTemplateId_ `number`: The template ID for the homepage.

### setIsInserterOpened

Opens or closes the inserter.

_Parameters_

-   _value_ `boolean|Object`: Whether the inserter should be opened (true) or closed (false). To specify an insertion point, use an object.
-   _value.rootClientId_ `string`: The root client ID to insert at.
-   _value.insertionIndex_ `number`: The index to insert at.

_Returns_

-   `Object`: Action object.

### setIsListViewOpened

Sets whether the list view panel should be open.

_Parameters_

-   _isOpen_ `boolean`: If true, opens the list view. If false, closes it. It does not toggle the state, but sets it directly.

### setIsNavigationPanelOpened

Sets whether the navigation panel should be open.

_Parameters_

-   _isOpen_ `boolean`: If true, opens the nav panel. If false, closes it. It does not toggle the state, but sets it directly.

### setNavigationPanelActiveMenu

Action that sets the active navigation panel menu.

_Parameters_

-   _menu_ `string`: Menu prop of active menu.

_Returns_

-   `Object`: Action object.

### setPage

Resolves the template for a page and displays both. If no path is given, attempts
to use the postId to generate a path like `?p=${ postId }`.

_Parameters_

-   _page_ `Object`: The page object.
-   _page.type_ `string`: The page type.
-   _page.slug_ `string`: The page slug.
-   _page.path_ `string`: The page path.
-   _page.context_ `Object`: The page context.

_Returns_

-   `number`: The resolved template ID for the page route.

### setTemplate

Action that sets a template, optionally fetching it from REST API.

_Parameters_

-   _templateId_ `number`: The template ID.
-   _templateSlug_ `string`: The template slug.

_Returns_

-   `Object`: Action object.

### setTemplatePart

Action that sets a template part.

_Parameters_

-   _templatePartId_ `string`: The template part ID.

_Returns_

-   `Object`: Action object.

### switchEditorMode

Undocumented declaration.

### toggleFeature

Dispatches an action that toggles a feature flag.

_Parameters_

-   _featureName_ `string`: Feature name.

### updateSettings

Returns an action object used to update the settings.

_Parameters_

-   _settings_ `Object`: New settings.

_Returns_

-   `Object`: Action object.

<!-- END TOKEN(Autogenerated actions|../../../packages/edit-site/src/store/actions.js) -->
